@@ -16,7 +16,7 @@ else:
     _component_func = components.declare_component("st_jsme", path=build_dir)
 
 
-def st_jsme(width: str, height: str, init_smile: str, key=None) -> str:
+def st_jsme(width: str, height: str, init_smile: str, key=None):
     component_value = _component_func(width=width, height=height, init_smiles=init_smile, key=key)
     return component_value
 
